RutaRoute class

Annotation used to mark a class as a Ruta route.

This annotation is typically used to indicate that a class represents a route in the Ruta framework.

Constructors

RutaRoute()
Creates a new instance of the RutaRoute annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited