OpenApiContact class

Represents the contact details of an API maintainer.

Constructors

OpenApiContact({String? name, String? email})
Creates a contact object for OpenAPI documentation.
const

Properties

email String?
Email address for contacting the API maintainers.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Name of the contact person or entity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts contact details into a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited