OpenApiLicence class

Represents licensing information for an API.

Constructors

OpenApiLicence({required String name, required String url})
Creates an OpenAPI-compliant license object.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name or identifier of the license.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
URL to the full license documentation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts license information into a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited