toMap method

Map<String, dynamic> toMap()

Converts the response into an OpenAPI-compliant map.

Returns a map where the status code is the key and the value is the detailed response specification.

Implementation

Map<String, dynamic> toMap() => {
      '$statusCode': innerMap(),
    };