Route class abstract

Abstract class for routes. Every route will inherit from this class

Constructors

Route()
Constructor

Properties

description String?
Description of the route, defaults to null
no setter
endpoints List<Endpoint>
List of endpoints for the route
getter/setter pair
externalDocs OpenApiExternalDocs?
External documentation for the route, defaults to null
no setter
hashCode int
The hash code for this object.
no setterinherited
middlewares List<Middleware>
List of middleware for request processing
no setter
name String
Returns the route name by extracting it from the class name
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Handler
Builds and returns a route handler with added middleware and endpoints
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited