OpenApiResponse class
Represents an HTTP response in an OpenAPI specification.
Constructors
Properties
- description → String?
-
A human-readable description of what this response means.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ List<
Field< ?Object> > -
List of fields defining the structure of the response body.
Uses generic Field
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
The HTTP status code for this response (e.g., 200, 404).
final
Methods
-
innerMap(
) → Map< String, dynamic> - Generates the detailed OpenAPI schema for the response.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts the response into an OpenAPI-compliant map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited