ValidationResult class
Represents the result of a validation process.
Constructors
-
ValidationResult.invalid(List<
String> errors) -
Factory constructor for an invalid validation result with a list of error messages.
factory
- ValidationResult.valid()
-
Factory constructor for a successful validation result (no errors).
factory
Properties
-
errors
→ List<
String> -
A list of error messages if the validation failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
Indicates whether the validation was successful.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited